documentationtools.ReSTLineageDirective
=======================================

.. abjad-lineage:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective

.. autoclass:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.append
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.argument
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.children
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.depth
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.depthwise_inventory
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.directive
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.extend
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.graph_order
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.improper_parentage
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.index
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.insert
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.leaves
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.name
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.node_class
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.nodes
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.options
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.parent
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.pop
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.proper_parentage
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.remove
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.rest_format
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.root
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__contains__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__copy__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__deepcopy__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__delitem__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__eq__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__format__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__getitem__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__iter__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__len__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__ne__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__repr__
      ~abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__setitem__

Bases
-----

- :py:class:`documentationtools.ReSTDirective <abjad.tools.documentationtools.ReSTDirective.ReSTDirective>`

- :py:class:`datastructuretools.TreeContainer <abjad.tools.datastructuretools.TreeContainer.TreeContainer>`

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.children
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.directive
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.leaves
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.node_class
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.nodes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.options
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.rest_format
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.argument
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.append
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.extend
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.index
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.insert
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.pop
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__contains__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__copy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__delitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__getitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__len__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.ReSTLineageDirective.ReSTLineageDirective.__setitem__
   :noindex:
